Function amazon_sp_vendor_transaction_status::apis::vendor_transaction_api::get_transaction
source · [−]pub async fn get_transaction(
configuration: &Configuration,
transaction_id: &str
) -> Result<GetTransactionResponse, Error>Expand description
Returns the status of the transaction that you specify. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 10 | 10 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.